@@ -35,12 +35,6 @@
 /* Define if log4cpp library is used. */
 /* #undef OPENSAML_LOG4CPP */
 
-#include <xercesc/util/XercesVersion.hpp>
-
-#if (XERCES_VERSION_MAJOR < 3)
-# define OPENSAML_XERCESC_HAS_XMLBYTE_RELEASE 1
-#endif
-
 /* Define to 1 if you have the <memory.h> header file. */
 #define HAVE_MEMORY_H 1
 
@@ -87,13 +81,13 @@
 #define PACKAGE_NAME "opensaml"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "opensaml 2.5.4"
+#define PACKAGE_STRING "opensaml 3.0.0"
 
 /* Define to the one symbol short name of this package. */
 #define PACKAGE_TARNAME "opensaml"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "2.5.4"
+#define PACKAGE_VERSION "3.0.0"
 
 /* Define to the necessary symbol if this constant uses a non-standard name on
    your system. */
@@ -106,10 +100,10 @@
 /* #undef TM_IN_SYS_TIME */
 
 /* Version number of package */
-#define VERSION "2.5.4"
+#define VERSION "3.0.0"
 
 /* Define to empty if `const' does not conform to ANSI C. */
 /* #undef const */
 
 /* Define to `unsigned' if <sys/types.h> does not define. */
-/* #undef size_t */
\ No newline at end of file
+/* #undef size_t */
